#
# spec file for package alsa-tools
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           alsa-tools
BuildRequires:  alsa-devel fdupes fltk-devel gcc-c++ gtk2-devel update-desktop-files
%define package_version	1.0.24.1
Url:            http://www.alsa-project.org/
Summary:        Various ALSA Tools
Version:        1.0.24.1
Release:        4.5.1
License:        GPLv2+
Group:          Productivity/Multimedia/Sound/Utilities
AutoReqProv:    on
Requires:       alsa-firmware, fxload
Source:         ftp://ftp.alsa-project.org/pub/tools/alsa-tools-%{package_version}.tar.bz2
Source1:        README.SuSE
Source2:        sbipatches.tar.bz2
Source3:        envy24control.desktop
Source4:        rmedigicontrol.desktop
Source7:        rme.png
Source8:        envy24.png
Patch:          alsa-tools-desktop-fix.dif
# Patch1:         alsa-tools-git-fixes.diff
Patch2:         hdspmixer-updates.diff
Patch99:        alsa-tools-1.0.24.1-fix.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Various tools for ALSA including DSP loaders.



Authors:
--------
    Jaroslav Kysela <perex@perex.cz>
    Takashi Iwai <tiwai@suse.de>
    Uros Bizjak <uros@kss-loka.si>

%package gui
Summary:        Various ALSA Tools with GUI
Group:          Productivity/Multimedia/Sound/Utilities
License:        GPLv2+
Requires:       pyalsa, python-gtk

%description gui
Various tools for ALSA with GUI for controlling the configuration and
the mixer of sepcific sound cards.



Authors:
--------
    Jaroslav Kysela <perex@perex.cz>
    Thomas Charbonnel <thomas@undata.org>
    Robert Vetter <postmaster@robertvetter.com>
    Martin Langer <martin-langer@gmx.de>

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Languages/C and C++
License:        GPLv2+
Requires:       alsa-tools = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.



Authors:
--------
    Jaroslav Kysela <perex@perex.cz>
    Takashi Iwai <tiwai@suse.de>
    Uros Bizjak <uros@kss-loka.si>

%prep
%setup -q -a 2 -n %{name}-%{package_version}
cp %{SOURCE1} .
%patch -p1
%patch99 -p1
%patch2 -p1
# %patch1 -p1

%build
export AUTOMAKE_JOBS=%{?jobs:%jobs}
for d in envy24control rmedigicontrol echomixer; do
  cp $d/configure.in-gtk2 $d/configure.in
done
ALL_PACKS="envy24control seq/sbiload sscape_ctl hdspconf hdsploader hdspmixer rmedigicontrol echomixer usx2yloader us428control as10k1 ld10k1 hwmixvolume"
%ifnarch ppc ppc64
ALL_PACKS="$ALL_PACKS sb16_csp"
%endif
for d in $ALL_PACKS; do
  (cd $d
  # aclocal
  # test -f Makefile.am && automake -a --foreign
  # autoconf
  autoreconf -fi
  %configure
  make %{?jobs:-j %jobs}
  )
done
# compile as10k1 examples
make -C as10k1/examples dsp

%install
ALL_PACKS="envy24control seq/sbiload sscape_ctl hdspconf hdsploader hdspmixer rmedigicontrol echomixer usx2yloader us428control as10k1 ld10k1 hwmixvolume"
%ifnarch ppc ppc64
ALL_PACKS="$ALL_PACKS sb16_csp"
%endif
for d in $ALL_PACKS; do
  (cd $d
  make DESTDIR="$RPM_BUILD_ROOT" install
  )
done
rm -f $RPM_BUILD_ROOT%{_libdir}/liblo10k1.la
# remove obsolete hotplug files
rm -rf $RPM_BUILD_ROOT/etc/hotplug
# install pixmaps
mkdir -p $RPM_BUILD_ROOT%{_datadir}/pixmaps
cp %{SOURCE7} $RPM_BUILD_ROOT%{_datadir}/pixmaps
cp %{SOURCE8} $RPM_BUILD_ROOT%{_datadir}/pixmaps
cp hdspmixer/pixmaps/hdspmixer.png $RPM_BUILD_ROOT%{_datadir}/pixmaps
cp hdspconf/pixmaps/hdspconf.png $RPM_BUILD_ROOT%{_datadir}/pixmaps
# install desktop files
%suse_update_desktop_file -i envy24control AudioVideo Mixer GTK
%suse_update_desktop_file -i rmedigicontrol AudioVideo Mixer GTK
%suse_update_desktop_file hdspconf AudioVideo Utility
%suse_update_desktop_file hdspmixer AudioVideo Mixer
# install documents
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
for d in $ALL_PACKS; do
  (cd $d
  n=${d##*/}
  mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}/$n
  for f in AUTHORS COPYING* ChangeLog NEWS README* TODO; do
    test -s $f || continue
    install -c -m 0644 $f $RPM_BUILD_ROOT%{_docdir}/%{name}/$n
  done
  )
done
# extra doc for ld10k1
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}/ld10k1/doc
cp ld10k1/doc/README $RPM_BUILD_ROOT%{_docdir}/%{name}/ld10k1/doc
cp ld10k1/doc/*.txt $RPM_BUILD_ROOT%{_docdir}/%{name}/ld10k1/doc
cp ld10k1/doc/*_usage $RPM_BUILD_ROOT%{_docdir}/%{name}/ld10k1/doc
# opl3 sounds
mkdir -p $RPM_BUILD_ROOT%{_datadir}/sounds/opl3
install -c -m 0644 *.o3 *.sb $RPM_BUILD_ROOT%{_datadir}/sounds/opl3
(cd as10k1
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}/as10k1/examples
cp examples/*.asm examples/*.emu10k1 $RPM_BUILD_ROOT%{_docdir}/%{name}/as10k1/examples
)
%fdupes -s $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%doc %{_docdir}/%{name}
%{_bindir}/sscape_ctl
%{_bindir}/sbiload
%ifnarch ppc ppc64
%{_bindir}/cspctl
%endif
%{_bindir}/hdsploader
%{_bindir}/usx2yloader
%{_bindir}/us428control
%{_mandir}/man?/*
%{_datadir}/sounds/opl3
%{_bindir}/as10k1
%{_sbindir}/ld10k1
%{_sbindir}/ld10k1d
%{_sbindir}/dl10k1
%{_bindir}/lo10k1
%{_bindir}/init_*
%{_datadir}/ld10k1
%{_libdir}/liblo10k1.so.*

%files gui
%defattr(-, root, root)
%{_bindir}/envy24control
%{_bindir}/rmedigicontrol
%{_bindir}/hdspconf
%{_bindir}/hdspmixer
%{_bindir}/echomixer
%{_bindir}/hwmixvolume
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*

%files devel
%defattr(-, root, root)
%{_includedir}/lo10k1
%{_libdir}/liblo10k1.so
%{_datadir}/aclocal/*.m4

%changelog
* Thu Mar 24 2011 tiwai@suse.de
- More updates/fixes of hdspmixer from the upstream (bnc#678389)
* Mon Mar 14 2011 tiwai@suse.de
- Update hdspmixer for fixing RME multiface & others (bnc#678389)
* Mon Jan 31 2011 tiwai@suse.de
- Updated to version 1.0.24.1:
  * including previous fixes
  * Add support of RME MADI, RayDAT and AIO
* Mon Apr 19 2010 tiwai@suse.de
- enabled hwmixvolme, using pyalsa and python-gtk
* Mon Apr 19 2010 tiwai@suse.de
- updated to version 1.0.23:
  * added hwmixvolume
* Fri Dec 18 2009 tiwai@suse.de
- updated to version 1.0.22:
  minor build fixes
* Mon Aug 31 2009 tiwai@suse.de
- updated to version 1.0.21:
  just a version bump including previous fixes
* Mon Jun  8 2009 tiwai@suse.de
- fix array range overflow in us428control (bnc#510855)
* Fri May 29 2009 tiwai@suse.de
- fix envy24control build error with the recent glibc
- remove obsoleted run_ldconfig macro
* Wed May  6 2009 tiwai@suse.de
- updated to version 1.0.20:
  * just a version bump
* Thu Mar  5 2009 ro@suse.de
- fix build
* Thu Jan 22 2009 tiwai@suse.de
- updated to version 1.0.19:
  * just minor packaging updates
* Wed Oct 29 2008 tiwai@suse.de
- updated to version 1.0.18-final:
  * cosmetic changes for Makefile and co.
* Tue Jul 15 2008 tiwai@suse.de
- updated to version 1.0.17-final:
  * just a version bump
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 1.0.17rc1:
  * managed by git now
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 1.0.16-final:
  * just a version bump
* Mon Jan 28 2008 tiwai@suse.de
- take back version number again (alsa-firmware should be fixed
  instead).
* Mon Jan 28 2008 dmueller@suse.de
- fix version number (alsa-tools and alsa-firmware have to be
  in sync)
* Tue Jan 22 2008 tiwai@suse.de
- updated to version 1.0.16rc1:
  * just a version bump
* Thu Dec 13 2007 tiwai@suse.de
- updated to HG 2007.12.15 version:
  * fix sbiload build with the new APIs
  * some hdspmixer fixes
* Mon Oct 22 2007 tiwai@suse.de
- fix build with gcc 4.3
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15-final:
  * Fix SPDIF input control on envy24control
* Tue Aug  7 2007 tiwai@suse.de
- don't build (broken) cspctl for powerpc
- don't install zero-size document files
* Wed Jun 20 2007 tiwai@suse.de
- fix errors in desktop files
- fix fdupes usage
* Fri Jun  8 2007 tiwai@suse.de
- fixed the previous broken patch.
- split to devel subpackage for some headers and libs.
- clean up spec file.
* Wed Jun  6 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Mon Jun  4 2007 tiwai@suse.de
- updated to version 1.0.14:
  * misc fixes for qlo10k1 for 64bit archs.
* Wed Mar 14 2007 tiwai@suse.de
- update to version 1.0.14rc3:
  * us428control bumped up to 0.4.6
  * ld10k1 ABI compat fixes
  * fix as10k1 max number of macros
* Tue Jan 16 2007 tiwai@suse.de
- use %%configure.
- take 1.0.14rc1 including the previous hg fix patches
* Tue Oct 17 2006 tiwai@suse.de
- fix wrong comparison with string literal (#211295)
- add mixxx mode to us428control
* Thu Oct  5 2006 tiwai@suse.de
- updated to version 1.0.13:
  * no real change since rc2.
* Fri Sep 22 2006 tiwai@suse.de
- updated to version 1.0.13rc2:
  * Fix ADC controls with higher resolution in envy24control
* Mon Jul 10 2006 tiwai@suse.de
- added fxload to Requires for Tascam usx2yloader (#190172)
* Tue Jul  4 2006 tiwai@suse.de
- updated to version 1.0.12rc1: just some compilation fixes for
  other systems
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.0.11-final.
  the SL1.1 patches have been merged.
* Thu Feb 23 2006 tiwai@suse.de
- added GTK to Categories in some desktop files
* Wed Feb 22 2006 tiwai@suse.de
- fix envy24control on Delta1010LT
* Thu Feb  9 2006 tiwai@suse.de
- fixed ice1712 wordclock setting (ALSA bug#1806).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 tiwai@suse.de
- fix eq10 for sblive
- improved envy24control UI
- removed *.la files.
* Mon Jan  2 2006 tiwai@suse.de
- updated to version 1.0.11rc2.
- fixed requires for alsa-firmware.
* Wed Dec 14 2005 tiwai@suse.de
- updated to version 1.0.11rc1.
* Wed Oct 12 2005 tiwai@suse.de
- updated to version 1.0.10rc2.
* Fri Sep  2 2005 tiwai@suse.de
- Fix segfault of envy24control (#115017)
* Thu Aug 18 2005 tiwai@suse.de
- removed obsolete hotplug files (#105276)
- fix bitops of ld10k1 to be 64bit clean.
* Thu Aug  4 2005 tiwai@suse.de
- updated to cvs 2005.08.04.
* Thu Jun  2 2005 tiwai@suse.de
- updated to version 1.0.9-final
- CVS updates 2005.06.02
* Tue May 24 2005 tiwai@suse.de
- updated to version 1.0.9rc4.
  as10k1, ld10k1 and echomixer are enabled.
* Thu Jan 13 2005 tiwai@suse.de
- updated to version 1.0.8-final.
* Wed Jan  5 2005 tiwai@suse.de
- updated to version 1.0.8rc2.
- split firmware data files to alsa-firmware package.
- removed loader programs replaced with hotplug fw loaders.
* Wed Nov 17 2004 tiwai@suse.de
- updated to version 1.0.7.
- fixed desktop files.
* Thu Sep 30 2004 tiwai@suse.de
- fixed hdsploader.c for the recent change of hdsp.h.
* Wed Sep 15 2004 tiwai@suse.de
- fixed segfault of envy24control with --help option.
- added the missing README.profiles for envy24control.
* Fri Aug 27 2004 tiwai@suse.de
- updated to version 1.0.6.
- added verbatim copying terms to alsa-firmware README.
* Fri Mar 19 2004 tiwai@suse.de
- fixed the header file path, now included in alsa-lib itself.
- improved/fixed envy24control.
* Mon Mar  1 2004 tiwai@suse.de
- updated to 1.0.3 final.
* Fri Feb 27 2004 tiwai@suse.de
- updated to version 1.0.3rc3.
- built with gtk2.
* Thu Feb 26 2004 tiwai@suse.de
- updated to version 1.0.3rc2.
* Mon Jan 12 2004 adrian@suse.de
- build as user
* Fri Jan  9 2004 tiwai@suse.de
- updated to version 1.0.1.
* Mon Nov 17 2003 tiwai@suse.de
- updated to version 1.0.0pre1.
* Mon Sep 15 2003 tiwai@suse.de
- fixed categories.
- added missing documents for mixartloader.
- added desktop icons.
* Tue Aug  5 2003 tiwai@suse.de
- added desktop files.
- call suse_update_desktop_file macro.
* Mon Jul 28 2003 tiwai@suse.de
- updated to version 0.9.6.
  hdspmixer is included in alsa-tools-gui package.
* Fri Jul 18 2003 tiwai@suse.de
- updated to version 0.9.6-pre.
- split GUI applications to gui subpackage.
* Wed Dec 18 2002 tiwai@suse.de
- updated to 0.9.0rc6.
- including the required header files from alsa-kernel.
- renamed a patch file to avoid the confliction of file names.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
- changed neededforbuild <xdevel> to <>
* Fri Sep  6 2002 tiwai@suse.de
- added the missing sbi patch files as tarball.
  (bug #19028)
* Wed Jul 31 2002 tiwai@suse.de
- removed xf86 from neededforbuild.
* Fri Jul  5 2002 tiwai@suse.de
- initial version: 0.9.0rc1; split off from alsa package.
